@@ -8,9 +8,10 @@ def cmd():
 
 @cmd.command()
 @click.option('--key', default=None, help="encrypt key string")
-@click.option('--file', default=None, help="file to be encrypt")
-def encrypt(key, file):
-    encrypt_file(file, key)
+@click.argument('fp', type=click.Path(exists=True))
+def encrypt(key, fp):
+    print(f"{fp} with key {key}")
+    encrypt_file(fp, key)
     click.echo('encrypted!')
 
 
